import { useState, useEffect } from 'react';
import { message } from 'antd';
import { getGenericDataPage, createGenericData, updateGenericData, deleteGenericData } from '@/services/GenericData';

export interface UseGenericDataOptions {
  module: string;
  type: string;
  defaultParams?: Record<string, any>;
  transform?: (data: any) => any;
  onError?: (error: any) => void;
}

export function useGenericData(options: UseGenericDataOptions) {
  const { module, type, defaultParams = {}, transform, onError } = options;
  
  const [loading, setLoading] = useState(false);
  const [dataSource, setDataSource] = useState<any[]>([]);
  const [total, setTotal] = useState(0);
  const [currentPage, setCurrentPage] = useState(1);
  const [pageSize, setPageSize] = useState(10);

  const fetchData = async (params: any = {}) => {
    // console.log('Fetching data with params:', params);
    setLoading(true);
    try {
      const response = await getGenericDataPage(module, type, {
        page: params.page || currentPage,
        size: params.size || pageSize,
        ...defaultParams,
        ...params
      });
      
      // console.log('API Response:', response);
      
      if (response.success) {
        const { items, total } = response.data;
        const itemsArray = Array.isArray(items) ? items : [];
        // console.log('Raw items:', itemsArray);
        
        const transformedData = itemsArray.map(item => ({
          ...item.data,
          _docId: item.id
        }));
        
        // console.log('Transformed data:', transformedData);
        
        setDataSource(transformedData);
        // console.log('DataSource after setState:', transformedData);
        setTotal(total);
      }
    } catch (error) {
      console.error('获取数据失败:', error);
      message.error('获取数据失败');
      onError?.(error);
    } finally {
      setLoading(false);
    }
  };

  const handleUpdate = async (record: any) => {
    // console.log('Updating record:', record);
    try {
      const docId = record._docId;
      if (!docId) {
        message.error('更新失败：找不到对应的记录');
        return;
      }
      const response = await updateGenericData(module, type, docId, record);
      if (response.success) {
        message.success('更新成功');
        // 立即重新获取数据
        await fetchData();
        // console.log('Data refreshed after update');
      }
    } catch (error) {
      console.error('更新失败:', error);
      message.error('更新失败');
      onError?.(error);
    }
  };

  const handleDelete = async (id: string) => {
    // console.log('Deleting record:', id);
    // console.log('dataSource', dataSource);
    try {
      // const record = dataSource.find(item => item.id?.toString() === id?.toString());
      // // const record = dataSource.find(item => item.id.toString() === id);
      // console.log('Found record to delete:', record);
      
      // if (!record?._docId) {
      //   message.error('删除失败：找不到对应的记录');
      //   return;
      // }
      const response = await deleteGenericData(module, type, id);
      if (response.success) {
        message.success('删除成功');
        // 立即重新获取数据
        await fetchData();
        // console.log('Data refreshed after delete');
      }
    } catch (error) {
      console.error('删除失败:', error);
      message.error('删除失败');
      onError?.(error);
    }
  };

  const handleAdd = async (data: any) => {
    // console.log('Adding new record:', data);
    try {
      const response = await createGenericData(module, type, data);
      if (response.success) {
        message.success('添加成功');
        // 立即重新获取数据
        await fetchData();
        // console.log('Data refreshed after add');
      }
    } catch (error) {
      console.error('添加失败:', error);
      message.error('添加失败');
      onError?.(error);
    }
  };
  
  const checkDataExists = async () => {
    try {
      const response = await getGenericDataPage(module, type, {
        page: 1,
        size: 1
      });
      return response.data.total > 0;
    } catch (error) {
      return false;
    }
  };

  // 添加一个effect来监听dataSource的变化
  // useEffect(() => {
  //   console.log('DataSource changed:', dataSource);
  // }, [dataSource]);

  return {
    loading,
    dataSource,
    total,
    currentPage,
    pageSize,
    setCurrentPage,
    setPageSize,
    fetchData,
    handleAdd,
    handleUpdate,
    handleDelete,
    checkDataExists
  };
} 