import React, { forwardRef, Ref, useImperativeHandle } from "react";
import styles from "./index.less";
import BaseModal from "@/components/BaseModal";
import { Flex } from "antd";
import classNames from "classnames";
import { useBoolean } from "ahooks";
import TodayEvent from "@/pages/SolidWaste/components/CleanRangeModal/components/TodayEvent";
import IndexItem from "./components/IndexItem";
import OperationCard from "./components/OperationCard";
import ProgressBar from "../PipeModal/components/ProgressBar";
import PipeInfoCard from "../PipeModal/components/PipeInfoCard";

interface AiLightingModalProps {
  data?: any;
}

interface CardProps {
  title: string;
  w: number;
  h: number;
  style?: React.CSSProperties;
  className?: string;
  children: React.ReactNode;
}

const Card: React.FC<CardProps> = (props) => {
  const { title, children, w, h, style, className } = props;
  return (
    <div
      className={classNames(styles.card, className)}
      style={{ ...style, width: w, height: h }}
    >
      <div className={styles.cardTitle}>{title}</div>
      <div>{children}</div>
    </div>
  );
};

export type CleanRangeModalMethod = {
  show: () => void;
  hide: () => void;
};

const AiLightingModal = forwardRef<CleanRangeModalMethod, AiLightingModalProps>(({ data }, ref) => {
  const [visible, action] = useBoolean(false);

  useImperativeHandle(ref, () => ({
    show: action.setTrue,
    hide: action.setFalse,
  }));

  const monthlyStats = data?.monthlyStats || [];
  const areaDistribution = data?.areaDistribution || [];

  return (
    <div className={styles.container}>
      <BaseModal
        open={visible}
        title="智慧照明"
        onCancel={action.setFalse}
        width={1524}
      >
        <div className={styles.content}>
          <Flex gap={15}>
            <div>
              <Card title="月度运行指标" w={878} h={188}>
                <div className={styles.leftTopWarp}>
                  {monthlyStats.map((item: any, index: number) => (
                    <IndexItem 
                      key={index}
                      data={item}
                      showIcon={index < 3} // 只有前三个显示图标
                    />
                  ))}
                </div>
              </Card>

              <div className={styles.leftButtomWarp}>
                <Card title="运行控监测与控制" w={428} h={543}>
                  <OperationCard
                    width={346}
                    height={172}
                    title="亮灯时长控制"
                    icon={require("@/assets/images/municipalFacilities/timeIcon.png")}
                  >
                    <div style={{ marginTop: 10 }}>
                      <div>每天</div>
                      <div>
                        <span className={styles.count}>{data?.control?.lightingTime?.on}</span>开灯
                      </div>
                      <div>
                        <span className={styles.count}>{data?.control?.lightingTime?.off}</span>关灯
                      </div>
                    </div>
                  </OperationCard>

                  <OperationCard
                    style={{ marginTop: 20 }}
                    width={346}
                    height={143}
                    title="动态照度控制"
                    icon={require("@/assets/images/municipalFacilities/kongzhizhaomiIc.png")}
                  >
                    <div style={{ marginTop: 10 }}>
                      <div>
                        {"光照<="} <span className={styles.count}>{data?.control?.brightness?.max}</span>
                        lux开灯
                      </div>
                      <div>
                        {"光照>= "}
                        <span className={styles.count}>{data?.control?.brightness?.min}</span>lux开灯
                      </div>
                    </div>
                  </OperationCard>
                </Card>
                
                <Card
                  title={"近一月照明故障"}
                  style={{ marginLeft: 20 }}
                  w={428}
                  h={543}
                >
                  <div className={styles.faultWarp}>
                    <PipeInfoCard
                      style={{ width: 147, height: 77, paddingTop: 2 }}
                      showRignt={false} data={{
                        label: data?.defects?.totalName,
                        count: data?.defects?.totalCount || 0,
                        unit: data?.defects?.totalUnit,
                       
                      }}                    />
                    <PipeInfoCard
                      style={{ width: 147, height: 77, paddingTop: 2 }}
                      showRignt={false} data={{
                        label: data?.defects?.timelyName,
                        count: data?.defects?.timelyCount || 0,
                        unit: data?.defects?.timelyUnit,
                       
                      }}                    />
                  </div>
                  <div>故障区域分布</div>
                  <div className={styles.detailContent}>
                    {areaDistribution.map((item: any, index: number) => {
                      return (
                        <div className={styles.areaItem} key={index}>
                          <span style={{ marginRight: 40 }}>{item.name}</span>
                          <ProgressBar value={item.value} total={item.total} />
                        </div>
                      );
                    })}
                  </div>
                </Card>
              </div>
            </div>
            <Card title="今日事件" w={566} h={761}>
              <TodayEvent data={data?.todayEvents} />
            </Card>
          </Flex>
        </div>
      </BaseModal>
    </div>
  );
});

export default AiLightingModal;
